@@ -1,5 +1,5 @@
 package Cpanel::JSON::XS;
-our $VERSION = '3.0212';
+our $VERSION = '3.0213';
 
 =pod
 
@@ -2109,21 +2109,26 @@ XSLoader::load 'Cpanel::JSON::XS', $VERSION;
 package
   JSON::PP::Boolean;
 
-use overload
-   "0+"     => sub { ${$_[0]} },
-   "++"     => sub { $_[0] = ${$_[0]} + 1 },
-   "--"     => sub { $_[0] = ${$_[0]} - 1 },
-   '""'     => sub { ${$_[0]} == 1 ? 'true' : '0' }, # GH 29
-   'eq'     => sub {
-     my ($obj, $op) = ref ($_[0]) ? ($_[0], $_[1]) : ($_[1], $_[0]);
-     if ($op eq 'true' or $op eq 'false') {
-       return "$obj" eq 'true' ? 'true' eq $op : 'false' eq $op;
-     }
-     else {
-       return $obj ? 1 == $op : 0 == $op;
-     }
-   },
-  fallback => 1;
+use overload ();
+
+BEGIN {
+  local $^W; # silence redefine warnings. no warnings 'redefine' does not help
+  &overload::import( 'overload', # workaround 5.6 reserved keyword warning
+    "0+"     => sub { ${$_[0]} },
+    "++"     => sub { $_[0] = ${$_[0]} + 1 },
+    "--"     => sub { $_[0] = ${$_[0]} - 1 },
+    '""'     => sub { ${$_[0]} == 1 ? 'true' : '0' }, # GH 29
+    'eq'     => sub {
+      my ($obj, $op) = ref ($_[0]) ? ($_[0], $_[1]) : ($_[1], $_[0]);
+      if ($op eq 'true' or $op eq 'false') {
+        return "$obj" eq 'true' ? 'true' eq $op : 'false' eq $op;
+      }
+      else {
+        return $obj ? 1 == $op : 0 == $op;
+      }
+    },
+    fallback => 1);
+}
 
 1;
 
